| Title: | Install Materials for Developing R Packages |
|---|---|
| Description: | Install learning materials for Developing R Packages. |
| Authors: | Malcolm Barrett [aut, cre] (ORCID: <https://orcid.org/0000-0003-0299-5825>) |
| Maintainer: | Malcolm Barrett <[email protected]> |
| License: | CC BY 4.0 |
| Version: | 0.0.1 |
| Built: | 2026-06-01 11:35:19 UTC |
| Source: | https://github.com/emptyfield-ds/rpkg.workshop |
browse_cloud() will open an RStudio Cloud version of a given learning
module in your browser. The cloud version will have the packages and
materials pre-installed.
browse_cloud(module, open = interactive())browse_cloud(module, open = interactive())
module |
The name of the module |
open |
Logical. Open the URL in the browser? Default is |
use_module() will install the materials for a given learning module. Then,
it will open a new RStudio Project containing the files you'll need for that
module.
use_module(module, destdir = NULL)use_module(module, destdir = NULL)
module |
The name of the module |
destdir |
The path on your computer where you would like the learning
materials installed. If |